# Revision Graph

A lightweight, customizable Git commit graph visualization library for Drupal. This library provides an interactive visualization of Git commit history with branch and merge visualization.

## Features

- Interactive Git commit graph visualization
- Branch and merge visualization
- Customizable styling and theming
- TypeScript support
- Lightweight and performant
- No external dependencies

## Installation

```bash
npm install revision-graph
```

## Usage

### Basic Setup

```typescript
import { RevisionGraph } from "revision-graph";

// Create a container element
const container = document.getElementById("revision-graph");

// Initialize the graph with options
const graph = new RevisionGraph({
  width: 800,
  nodeHeight: 40,
  nodeWidth: 20,
  columnWidth: 50,
  colors: ["#e11d21", "#fbca04", "#009800", "#006b75", "#207de5", "#0052cc", "#5319e7"],
  showLabels: true,
  theme: "light"
});

// Render the graph
const graphGenerator = graph.renderGraph(container, commits);

// Render the commit list
const listGenerator = graph.renderList(container, commits);
```

### Type Definitions

```typescript
interface Commit {
  id: string;
  message: string;
  author: string;
  timestamp: number;
  parents: string[];
  refs?: string[];
  tags?: Tag[];
  urls?: CommitUrl[];
}

interface Tag {
  name: string;
  color: string;
  label: string;
}

interface CommitUrl {
  label: string;
  url: string;
}

interface GraphOptions {
  width: number;
  nodeHeight: number;
  nodeWidth: number;
  columnWidth: number;
  colors: string[];
  showLabels: boolean;
  theme: "light" | "dark";
}
```

## Development

### Prerequisites

- Node.js (v14 or higher)
- npm (v6 or higher)

### Setup

1. Clone the repository:
```bash
git clone https://github.com/yourusername/revision-graph.git
cd revision-graph
```

2. Install dependencies:
```bash
npm install
```

3. Build the library:
```bash
npm run build
```

### Available Scripts

- `npm run build` - Build the library
- `npm run lint` - Run ESLint
- `npm run type-check` - Run TypeScript type checking
- `npm test` - Run tests

